ams.interface.Dynamic
=====================

.. currentmodule:: ams.interface

.. autoclass:: Dynamic

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Dynamic.link_andes
       
       
          ~Dynamic.receive
       
       
          ~Dynamic.send
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Dynamic.is_tds
   
   